@@ -1,5 +1,4 @@
 def construct_dict_from_dotkv(dict = {}, fields = [], value = None):
-    from outfit import Logger
     if len(fields) <= 1:
         dict[fields[0]] = value
     else:
@@ -18,9 +17,8 @@ def construct_dotkv_from_dict(source = {}, key = '', temp_result = {}):
     return temp_result   
 
 def merge_dict(dict1, dict2):
-    from outfit import Logger
-    dotkv1 = construct_dotkv_from_dict(source = dict1)
-    dotkv2 = construct_dotkv_from_dict(source = dict2)
+    dotkv1 = construct_dotkv_from_dict(source = dict1, key = '', temp_result = {})
+    dotkv2 = construct_dotkv_from_dict(source = dict2, key = '', temp_result = {})
     set1 = set(dotkv1)
     set2 = set(dotkv2)
     
@@ -28,7 +26,6 @@ def merge_dict(dict1, dict2):
     
     union_dict = {} 
     for key in union:
-        Logger.debug(key)
         union_dict = construct_dict_from_dotkv(
             union_dict, key.split('.'), dotkv2[key] if key in set2 else dotkv1[key])
     
