@@ -1,5 +1,6 @@
 import os
 import yaml
+from .logger import Logger
 
 def load_yaml(path):
     current_path = os.getcwd()
@@ -21,3 +22,9 @@ def load_yaml(path):
             Logger.error('error load yaml file ' + str(err))
 
     return content
+
+def convert_yaml(stream):
+    try:
+        return yaml.safe_load(stream)
+    except yaml.YAMLError as err:
+        Logger.error('error load yaml stream text ' + str(err)) 
